
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.lang
import java.util
import jneqsim.neqsim.processSimulation
import jneqsim.neqsim.processSimulation.processEquipment
import jneqsim.neqsim.processSimulation.processEquipment.stream
import typing



class HeaterInterface(jneqsim.neqsim.processSimulation.SimulationInterface):
    def setOutPressure(self, double: float, string: typing.Union[java.lang.String, str]) -> None: ...
    def setOutTP(self, double: float, double2: float) -> None: ...
    def setOutTemperature(self, double: float, string: typing.Union[java.lang.String, str]) -> None: ...
    def setdT(self, double: float) -> None: ...

class ReBoiler(jneqsim.neqsim.processSimulation.processEquipment.TwoPortEquipment):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str], streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    @typing.overload
    def __init__(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    def displayResult(self) -> None: ...
    def getReboilerDuty(self) -> float: ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...
    def setReboilerDuty(self, double: float) -> None: ...

class HeatExchangerInterface(HeaterInterface):
    def getOutStream(self, int: int) -> jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface: ...

class Heater(jneqsim.neqsim.processSimulation.processEquipment.TwoPortEquipment, HeaterInterface):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str]): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str], streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    @typing.overload
    def __init__(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    def displayResult(self) -> None: ...
    def getDuty(self) -> float: ...
    def getEnergyInput(self) -> float: ...
    def getEntropyProduction(self, string: typing.Union[java.lang.String, str]) -> float: ...
    def getExergyChange(self, string: typing.Union[java.lang.String, str], double: float) -> float: ...
    def getPressureDrop(self) -> float: ...
    def isSetEnergyInput(self) -> bool: ...
    def needRecalculation(self) -> bool: ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...
    @typing.overload
    def runTransient(self, double: float) -> None: ...
    @typing.overload
    def runTransient(self, double: float, uUID: java.util.UUID) -> None: ...
    def setDuty(self, double: float) -> None: ...
    def setEnergyInput(self, double: float) -> None: ...
    @typing.overload
    def setOutPressure(self, double: float) -> None: ...
    @typing.overload
    def setOutPressure(self, double: float, string: typing.Union[java.lang.String, str]) -> None: ...
    def setOutStream(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface) -> None: ...
    def setOutTP(self, double: float, double2: float) -> None: ...
    @typing.overload
    def setOutTemperature(self, double: float) -> None: ...
    @typing.overload
    def setOutTemperature(self, double: float, string: typing.Union[java.lang.String, str]) -> None: ...
    def setPressureDrop(self, double: float) -> None: ...
    def setSetEnergyInput(self, boolean: bool) -> None: ...
    def setdT(self, double: float) -> None: ...
    def toJson(self) -> java.lang.String: ...

class Cooler(Heater):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str]): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str], streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    @typing.overload
    def __init__(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    def getEntropyProduction(self, string: typing.Union[java.lang.String, str]) -> float: ...
    def toJson(self) -> java.lang.String: ...

class HeatExchanger(Heater, HeatExchangerInterface):
    guessOutTemperature: float = ...
    thermalEffectiveness: float = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str]): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str], streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str], streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface, streamInterface2: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    @typing.overload
    def __init__(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    @typing.overload
    def __init__(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface, streamInterface2: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    def addInStream(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface) -> None: ...
    def calcThermalEffectivenes(self, double: float, double2: float) -> float: ...
    def displayResult(self) -> None: ...
    def getDuty(self) -> float: ...
    def getEntropyProduction(self, string: typing.Union[java.lang.String, str]) -> float: ...
    def getFlowArrangement(self) -> java.lang.String: ...
    def getGuessOutTemperature(self) -> float: ...
    def getHotColdDutyBalance(self) -> float: ...
    @typing.overload
    def getInStream(self) -> jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface: ...
    @typing.overload
    def getInStream(self, int: int) -> jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface: ...
    def getInTemperature(self, int: int) -> None: ...
    def getMassBalance(self, string: typing.Union[java.lang.String, str]) -> float: ...
    @typing.overload
    def getOutStream(self) -> jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface: ...
    @typing.overload
    def getOutStream(self, int: int) -> jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface: ...
    def getOutTemperature(self, int: int) -> None: ...
    def getThermalEffectiveness(self) -> float: ...
    def getUAvalue(self) -> float: ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...
    @typing.overload
    def runConditionAnalysis(self) -> None: ...
    @typing.overload
    def runConditionAnalysis(self, processEquipmentInterface: jneqsim.neqsim.processSimulation.processEquipment.ProcessEquipmentInterface) -> None: ...
    def runSpecifiedStream(self, uUID: java.util.UUID) -> None: ...
    def setFeedStream(self, int: int, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface) -> None: ...
    def setFlowArrangement(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setGuessOutTemperature(self, double: float) -> None: ...
    def setHotColdDutyBalance(self, double: float) -> None: ...
    def setName(self, string: typing.Union[java.lang.String, str]) -> None: ...
    @typing.overload
    def setOutStream(self, int: int, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface) -> None: ...
    @typing.overload
    def setOutStream(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface) -> None: ...
    @typing.overload
    def setOutTemperature(self, double: float) -> None: ...
    @typing.overload
    def setOutTemperature(self, double: float, string: typing.Union[java.lang.String, str]) -> None: ...
    def setThermalEffectiveness(self, double: float) -> None: ...
    def setUAvalue(self, double: float) -> None: ...
    def setdT(self, double: float) -> None: ...

class NeqHeater(Heater):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str]): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str], streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    @typing.overload
    def __init__(self, streamInterface: jneqsim.neqsim.processSimulation.processEquipment.stream.StreamInterface): ...
    def displayResult(self) -> None: ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...
    @typing.overload
    def setOutTemperature(self, double: float, string: typing.Union[java.lang.String, str]) -> None: ...
    @typing.overload
    def setOutTemperature(self, double: float) -> None: ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("jneqsim.neqsim.processSimulation.processEquipment.heatExchanger")``.

    Cooler: typing.Type[Cooler]
    HeatExchanger: typing.Type[HeatExchanger]
    HeatExchangerInterface: typing.Type[HeatExchangerInterface]
    Heater: typing.Type[Heater]
    HeaterInterface: typing.Type[HeaterInterface]
    NeqHeater: typing.Type[NeqHeater]
    ReBoiler: typing.Type[ReBoiler]
